#------------------------------------------------------------------
#
# Dec. 2008 - Vimaladevi Rajakanthan (vrajakan@cisco.com)
#
# Copyright (c) 2008 by cisco Systems, Inc.
# All rights reserved.
#
# Version-date: v2.0-12/19/2008
#
# Name: bgp_lib.tcl
#
# Desc: lib procedures to be shared by eem policies
#
#------------------------------------------------------------------


###############################################################################
#
#   Description: The procedure to send error message for invalid values
#
#   IN: policy name, invalid value and a string 
#   OUT:  Outputs error message and exits from the policy 
#
###############################################################################

proc errorMessage {policy invalid_val str} {

    set err "\n\n$invalid_val IS NOT VALID, $str SO FURTHER DIAGNOSIS IS *NOT*\
             PERFORMED FOR THE POLICY $policy\n\n"
    action_syslog msg $err
    exit 0

}

###############################################################################
#
#   Description:  Get the peer-group name for the ip address passed to it by
#                 parsing the output of "show ip bgp neighbor x.x.x.x" 
#
#   IN:  ip address of the neighbor 
#   OUT: Returns peer-group name 
#
###############################################################################

proc parse_peer_group_name {ipaddr} {

    set pg_name ""

    set output [parse_show_command_output "show ip bgp neighbor $ipaddr" \
                "Member of peer-group"]
    if {[llength $output] != 0} {
        set output [lindex $output 0]
        regsub -all {[ \t]+} $output " " out
        string trim $out
        set pg_name [lindex $out 3]
    }
    return $pg_name
}

