#------------------------------------------------------------------
#
# Dec. 2008 - Vimaladevi Rajakanthan (vrajakan@cisco.com)
#
# Copyright (c) 2008 by cisco Systems, Inc.
# All rights reserved.
#
# Version-date: v2.0-12/19/2008
#
# Name: sdiag_lib.tcl
#
# Desc: lib procedures to be shared by eem policies
#
#------------------------------------------------------------------

global errorInfo

###############################################################################
#
#   Description: IOS super user command.
#                This is for getting ios super command under enable mode.
#                such as show command etc.
#
#   IN: ios cli command which needs to be executed.
#   OUT: Returns show command output
#
###############################################################################

proc exec_show_commands {command} {
    
    global errorInfo

    if [catch {cli_open} result] {
        error $result $errorInfo
    } else {
        array set cli1 $result
    }

    if [catch {cli_exec $cli1(fd) "enable"} result] {
        error $result $errorInfo
    }

    if [catch {cli_exec $cli1(fd) $command} result] {
        error $result $errorInfo
    } else {
        set show_command_output $result
    }

    if [catch {cli_close $cli1(fd) $cli1(tty_id)} result] {
        error $result $errorInfo
    }

    return $show_command_output
}

###############################################################################
#
#   Description: Executes the show command that is passed as an argument 
#                and parses the output of the show command to grep for the
#                pattern passed as input 
#
#   IN: command and the keyword to grep for in the command output 
#   OUT: Returns the matching line of the output
#
###############################################################################

proc parse_show_command_output {command keyword} {

    set config ""
    set matching_config {} 

    if {$command != ""} {
        set output [exec_show_commands $command]
        foreach x [split $output "\n"] {
            if {[regexp "$keyword" $x config] == 1} {
                lappend matching_config $x
            }
        }
    }

    return $matching_config
}

###############################################################################
#
#   Description: Procedure to parse a normal table output of an exec command
#                on the router 
#
#   IN: output that has the table and keyword to look for the table 
#   OUT: Returns the header and table values  
#
###############################################################################

proc parse_table { output str } {

    set table_val {}
    set key [split $str " "]
    if {$output != ""} {
        set temp [split $output "\n"]
        for {set a 0} {$a < [llength $temp]} {incr a} {
            set pattern [lindex $temp $a]
            if {([regexp "[lindex $key 0]" $pattern match1] == 1) && \
                ([regexp "[lindex $key 1]" $pattern match2] == 1) && \
                ([regexp "[lindex $key 2]" $pattern match3] == 1) } {
                set name [info hostname]
                for {set b [expr $a + 1]} {$b < [llength $temp]} {incr b} {
                    if {[regexp "$name#" [lindex $temp $b]] != 1} {
                        lappend table_val [lindex $temp  $b]
                    }
                }
            }
        }
    }
    return $table_val
}

# procedure to parse header and table values in a table ouput of show command
# from a router

###############################################################################
#
#   Description: Procedure to parse header and table values after massaging 
#                the table output 
#
#   IN: table values with the format as it appears on the router 
#   OUT: Returns the header and table values as a list
#
###############################################################################

proc parse_header_and_values {table_contents} {

    set contents {}
    set len [llength $table_contents]
    if {$len != 0} {
        for {set a 0} {$a < $len} {incr a} {
            set str [lindex $table_contents $a]
            string trim $str
            regsub -all {[ \t]+} $str " " output
            lappend contents $output
        }
    }
    return $contents
}

